==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/EC2/CertificateAuthenticationRequest.pm <==
package Paws::EC2::CertificateAuthenticationRequest;
  use Moose;
  has ClientRootCertificateChainArn => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CertificateAuthenticationRequest

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::EC2::CertificateAuthenticationRequest object:

  $service_obj->Method(Att1 => { ClientRootCertificateChainArn => $value, ..., ClientRootCertificateChainArn => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::EC2::CertificateAuthenticationRequest object:

  $result = $service_obj->Method(...);
  $result->Att1->ClientRootCertificateChainArn

=head1 DESCRIPTION

This class has no description

=head1 ATTRIBUTES


=head2 ClientRootCertificateChainArn => Str

  B<The ARN of the client certificate. The certificate must be signed by
a certificate authority (CA) and it must be provisioned in AWS
Certificate Manager (ACM).>



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/EC2/CertificateAuthenticationRequest.pm <==
package Paws::EC2::CertificateAuthenticationRequest;
  use Moose;
  has ClientRootCertificateChainArn => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CertificateAuthenticationRequest

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::EC2::CertificateAuthenticationRequest object:

  $service_obj->Method(Att1 => { ClientRootCertificateChainArn => $value, ..., ClientRootCertificateChainArn => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::EC2::CertificateAuthenticationRequest object:

  $result = $service_obj->Method(...);
  $result->Att1->ClientRootCertificateChainArn

=head1 DESCRIPTION

This class has no description

=head1 ATTRIBUTES


=head2 ClientRootCertificateChainArn => Str

  The ARN of the client certificate. The certificate must be signed by a
certificate authority (CA) and it must be provisioned in AWS
Certificate Manager (ACM).



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
